The filter_nonzero_bases function filters out bases functions that are essentially zero.
Bases functions with a sum of absolute values less than a threshold (\(10^{-10}\)) are considered as essentially zero and are filtered out.
Usage
filter_nonzero_bases(bases)
Value
A list with the following components:
filtered_bases
A matrix containing the filtered bases functions, removing those that are essentially zero.
selected_bases
A vector containing the indices of the selected bases functions after filtering.